@@ -1,7 +1,7 @@
 __package_name__ = 'formatter'
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 __author__ = 'Rick van Hattem'
-__author_email__ = 'Rick.van.Hattem@Fawo.nl'
+__author_email__ = 'Wolph@wol.ph'
 __description__ = '''A Python source formatter that uses the tokenize library
 to ensure correctness'''
 __url__ = 'https://github.com/WoLpH/formatter'
